@@ -21,8 +21,10 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"io/ioutil"
 	"net"
 	"os"
+	"path/filepath"
 	"strconv"
 	"strings"
 	"syscall"
@@ -35,12 +37,13 @@ import (
 	"github.com/hashicorp/errwrap"
 	"github.com/vishvananda/netlink"
 
-	"github.com/coreos/rkt/common"
-	"github.com/coreos/rkt/networking/tuntap"
+	"github.com/rkt/rkt/common"
+	commonnet "github.com/rkt/rkt/common/networking"
+	"github.com/rkt/rkt/networking/tuntap"
 )
 
 const (
-	defaultBrName     = "kvm-cni0"
+	defaultBrName     = "cni0"
 	defaultSubnetFile = "/run/flannel/subnet.env"
 	defaultMTU        = 1500
 )
@@ -94,7 +97,7 @@ func setupMacVTapDevice(podID types.UUID, config MacVTapNetConf, interfaceNumber
 	var mode netlink.MacvlanMode
 	switch config.Mode {
 	// if not set - defaults to bridge mode as in:
-	// https://github.com/coreos/rkt/blob/master/Documentation/networking.md#macvlan
+	// https://github.com/rkt/rkt/blob/master/Documentation/networking.md#macvlan
 	case "", "bridge":
 		mode = netlink.MACVLAN_MODE_BRIDGE
 	case "private":
@@ -169,7 +172,7 @@ func kvmSetupNetAddressing(network *Networking, n activeNet, ifName string) erro
 		return fmt.Errorf("net-plugin returned no IPv4 configuration")
 	}
 
-	n.runtime.IP, n.runtime.Mask, n.runtime.HostIP, n.runtime.IP4 = result.IP4.IP.IP, net.IP(result.IP4.IP.Mask), result.IP4.Gateway, result.IP4
+	n.runtime.MergeCNIResult(result)
 
 	return nil
 }
@@ -378,6 +381,10 @@ func kvmTransformFlannelNetwork(net *activeNet) error {
 		n.Delegate["type"] = "bridge"
 	}
 
+	if !hasKey(n.Delegate, "isDefaultGateway") {
+		n.Delegate["isDefaultGateway"] = false
+	}
+
 	if !hasKey(n.Delegate, "ipMasq") {
 		// if flannel is not doing ipmasq, we should
 		ipmasq := !fenv.ipmasq
@@ -420,13 +427,14 @@ func kvmTransformFlannelNetwork(net *activeNet) error {
 	net.conf.Type = n.Delegate["type"].(string)
 	net.conf.IPMasq = n.Delegate["ipMasq"].(bool)
 	net.conf.MTU = n.Delegate["mtu"].(int)
+	net.conf.IsDefaultGateway = n.Delegate["isDefaultGateway"].(bool)
 	net.conf.IPAM.Type = "host-local"
 	return nil
 }
 
 // kvmSetup prepare new Networking to be used in kvm environment based on tuntap pair interfaces
 // to allow communication with virtual machine created by lkvm tool
-func kvmSetup(podRoot string, podID types.UUID, fps []ForwardedPort, netList common.NetList, localConfig string) (*Networking, error) {
+func kvmSetup(podRoot string, podID types.UUID, fps []commonnet.ForwardedPort, netList common.NetList, localConfig string, noDNS bool) (*Networking, error) {
 	network := Networking{
 		podEnv: podEnv{
 			podRoot:      podRoot,
@@ -436,11 +444,28 @@ func kvmSetup(podRoot string, podID types.UUID, fps []ForwardedPort, netList com
 		},
 	}
 	var e error
+
+	// If there's a network set as default in CNI configuration
+	defaultGatewaySet := false
+
+	_, defaultNet, err := net.ParseCIDR("0.0.0.0/0")
+	if err != nil {
+		return nil, errwrap.Wrap(errors.New("error when parsing net address"), err)
+	}
+
 	network.nets, e = network.loadNets()
 	if e != nil {
 		return nil, errwrap.Wrap(errors.New("error loading network definitions"), e)
 	}
 
+	// did stage0 already make /etc/rkt-resolv.conf (i.e. --dns passed)
+	resolvPath := filepath.Join(common.Stage1RootfsPath(podRoot), "etc/rkt-resolv.conf")
+	_, err = os.Stat(resolvPath)
+	if err != nil && !os.IsNotExist(err) {
+		return nil, errwrap.Wrap(fmt.Errorf("error statting /etc/rkt-resolv.conf"), err)
+	}
+	podHasResolvConf := err == nil
+
 	for i, n := range network.nets {
 		if n.conf.Type == "flannel" {
 			if err := kvmTransformFlannelNetwork(&n); err != nil {
@@ -517,6 +542,15 @@ func kvmSetup(podRoot string, podID types.UUID, fps []ForwardedPort, netList com
 				return nil, err
 			}
 
+			if n.conf.IsDefaultGateway {
+				n.runtime.IP4.Routes = append(
+					n.runtime.IP4.Routes,
+					cnitypes.Route{Dst: *defaultNet, GW: n.runtime.IP4.Gateway},
+				)
+				defaultGatewaySet = true
+				config.IsGw = true
+			}
+
 			if config.IsGw {
 				err = ensureHasAddr(
 					br,
@@ -552,9 +586,36 @@ func kvmSetup(podRoot string, podID types.UUID, fps []ForwardedPort, netList com
 			return nil, fmt.Errorf("network %q have unsupported type: %q", n.conf.Name, n.conf.Type)
 		}
 
+		// Check if there's any other network set as default gateway
+		if defaultGatewaySet {
+			for _, route := range n.runtime.IP4.Routes {
+				if (defaultNet.String() == route.Dst.String()) && !n.conf.IsDefaultGateway {
+					return nil, fmt.Errorf("flannel config enables default gateway and IPAM sets default gateway via %q", n.runtime.IP4.Gateway)
+				}
+			}
+		}
+
+		// Generate rkt-resolv.conf if it's not already there.
+		// The first network plugin that supplies a non-empty
+		// DNS response will win, unless noDNS is true (--dns passed to rkt run)
+		if !common.IsDNSZero(&n.runtime.DNS) && !noDNS {
+			if !podHasResolvConf {
+				err := ioutil.WriteFile(
+					resolvPath,
+					[]byte(common.MakeResolvConf(n.runtime.DNS, "Generated by rkt from network "+n.conf.Name)),
+					0644)
+				if err != nil {
+					return nil, errwrap.Wrap(fmt.Errorf("error creating resolv.conf"), err)
+				}
+				podHasResolvConf = true
+			} else {
+				stderr.Printf("Warning: network %v plugin specified DNS configuration, but DNS already supplied", n.conf.Name)
+			}
+		}
+
 		if n.conf.IPMasq {
 			chain := cniutils.FormatChainName(n.conf.Name, podID.String())
-			comment := cniutils.FormatChainName(n.conf.Name, podID.String())
+			comment := cniutils.FormatComment(n.conf.Name, podID.String())
 			if err := ip.SetupIPMasq(&net.IPNet{
 				IP:   n.runtime.IP,
 				Mask: net.IPMask(n.runtime.Mask),
@@ -568,7 +629,12 @@ func kvmSetup(podRoot string, podID types.UUID, fps []ForwardedPort, netList com
 	if err != nil {
 		return nil, err
 	}
+	if err := network.setupForwarding(); err != nil {
+		network.teardownForwarding()
+		return nil, err
+	}
 	if err := network.forwardPorts(fps, podIP); err != nil {
+		network.teardownForwarding()
 		return nil, err
 	}
 
@@ -638,7 +704,7 @@ func (n *Networking) teardownKvmNets() {
 // similar to Networking.Teardown but without host namespaces
 func (n *Networking) kvmTeardown() {
 
-	if err := n.unforwardPorts(); err != nil {
+	if err := n.teardownForwarding(); err != nil {
 		stderr.PrintE("error removing forwarded ports (kvm)", err)
 	}
 	n.teardownKvmNets()
