@@ -30,10 +30,10 @@ import (
 	"github.com/appc/spec/schema"
 	"github.com/appc/spec/schema/types"
 	"github.com/hashicorp/errwrap"
+	"github.com/opencontainers/selinux/go-selinux/label"
 	"github.com/pborman/uuid"
 	"github.com/rkt/rkt/common"
 	"github.com/rkt/rkt/networking/netinfo"
-	"github.com/rkt/rkt/pkg/label"
 	"github.com/rkt/rkt/pkg/lock"
 	"github.com/rkt/rkt/pkg/sys"
 )
@@ -269,7 +269,7 @@ func getPod(dataDir string, uuid *types.UUID) (*Pod, error) {
 
 	p.FileLock = l
 
-	if p.isRunning() {
+	if p.isRunning() || p.isExit() {
 		cfd, err := p.Fd()
 		if err != nil {
 			return nil, errwrap.Wrap(fmt.Errorf("error acquiring pod %v dir fd", uuid), err)
@@ -414,8 +414,7 @@ func (p *Pod) ToRun() error {
 	if err := p.ExclusiveLock(); err != nil {
 		return err
 	}
-
-	label.Relabel(p.Path(), p.MountLabel, "Z")
+	label.Relabel(p.Path(), p.MountLabel, false)
 	if err := os.Rename(p.Path(), p.runPath()); err != nil {
 		// TODO(vc): we could race here with a concurrent ToRun(), let caller deal with the error.
 		return err
@@ -1200,6 +1199,11 @@ func (p *Pod) IsFinished() bool {
 	return p.isExited || p.isAbortedPrepare || p.isGarbage || p.isGone
 }
 
+// isExit returns true if the pod is in exited states
+func (p *Pod) isExit() bool {
+	return p.isExited
+}
+
 // AppExitCode returns the app's exit code.
 // It returns an error if the exit code file doesn't exit or the content of the file is invalid.
 func (p *Pod) AppExitCode(appName string) (int, error) {
