@@ -27,9 +27,9 @@ import (
 	"testing"
 	"time"
 
-	"github.com/coreos/rkt/pkg/multicall"
-	"github.com/coreos/rkt/pkg/sys"
-	"github.com/coreos/rkt/pkg/user"
+	"github.com/rkt/rkt/pkg/multicall"
+	"github.com/rkt/rkt/pkg/sys"
+	"github.com/rkt/rkt/pkg/user"
 )
 
 func init() {
