@@ -1,4 +1,4 @@
-// Copyright 2015 The rkt Authors
+// Copyright 2015-2017 The rkt Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -22,8 +22,8 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/coreos/rkt/common/apps"
 	"github.com/hashicorp/errwrap"
+	"github.com/rkt/rkt/common/apps"
 
 	"github.com/appc/spec/schema"
 	"github.com/appc/spec/schema/types"
@@ -49,6 +49,9 @@ func parseApps(al *apps.Apps, args []string, flags *pflag.FlagSet, allowAppArgs
 	inAppArgs := false
 	for i := 0; i < len(args); i++ {
 		a := args[i]
+		if len(a) == 0 {
+			continue
+		}
 		if inAppArgs {
 			switch a {
 			case "---":
@@ -600,10 +603,47 @@ func (au *appName) Type() string {
 	return "appName"
 }
 
-// appAnnotation is for --user-annotation flags in the form of: --user-annotation=NAME=VALUE.
+// appAnnotation is for --annotation flags in the form of: --annotation=name=value
 type appAnnotation apps.Apps
 
 func (au *appAnnotation) Set(s string) error {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return fmt.Errorf("--annotation must follow an image")
+	}
+
+	fields := strings.SplitN(s, "=", 2)
+	if len(fields) != 2 {
+		return fmt.Errorf("invalid format of --annotation flag %q", s)
+	}
+
+	if app.Annotations == nil {
+		app.Annotations = make(map[string]string)
+	}
+	app.Annotations[fields[0]] = fields[1]
+	return nil
+}
+
+func (au *appAnnotation) String() string {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return ""
+	}
+	var annotations []string
+	for name, value := range app.Annotations {
+		annotations = append(annotations, fmt.Sprintf("%s=%s", name, value))
+	}
+	return strings.Join(annotations, ",")
+}
+
+func (au *appAnnotation) Type() string {
+	return "appAnnotation"
+}
+
+// appUserAnnotation is for --user-annotation flags in the form of: --user-annotation=NAME=VALUE.
+type appUserAnnotation apps.Apps
+
+func (au *appUserAnnotation) Set(s string) error {
 	app := (*apps.Apps)(au).Last()
 	if app == nil {
 		return fmt.Errorf("--user-annotation must follow an image")
@@ -621,7 +661,7 @@ func (au *appAnnotation) Set(s string) error {
 	return nil
 }
 
-func (au *appAnnotation) String() string {
+func (au *appUserAnnotation) String() string {
 	app := (*apps.Apps)(au).Last()
 	if app == nil {
 		return ""
@@ -633,8 +673,8 @@ func (au *appAnnotation) String() string {
 	return strings.Join(annotations, ",")
 }
 
-func (au *appAnnotation) Type() string {
-	return "appAnnotation"
+func (au *appUserAnnotation) Type() string {
+	return "appUserAnnotation"
 }
 
 // appLabel is for --user-label flags in the form of: --user-label=NAME=VALUE.
@@ -794,3 +834,104 @@ func (au *appSupplementaryGIDs) String() string {
 func (au *appSupplementaryGIDs) Type() string {
 	return "appSupplementaryGIDs"
 }
+
+// `--stdin=mode` flag
+type appStdin apps.Apps
+
+func (au *appStdin) Set(s string) error {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return fmt.Errorf("--stdin must follow an application")
+	}
+	allowedInModes := map[string]apps.AppIO{
+		apps.AppIONull.String():   apps.AppIONull,
+		apps.AppIOStream.String(): apps.AppIOStream,
+		apps.AppIOTTY.String():    apps.AppIOTTY,
+	}
+	mode, ok := allowedInModes[s]
+	if !ok {
+		return fmt.Errorf("invalid stdin mode %q", s)
+	}
+	app.Stdin = mode
+	return nil
+}
+
+func (au *appStdin) String() string {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return ""
+	}
+	return app.Stdin.String()
+}
+
+func (au *appStdin) Type() string {
+	return "appStdin"
+}
+
+// `--stdout=mode` flag
+type appStdout apps.Apps
+
+func (au *appStdout) Set(s string) error {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return fmt.Errorf("--stdout must follow an application")
+	}
+	allowedOutModes := map[string]apps.AppIO{
+		apps.AppIOLog.String():    apps.AppIOLog,
+		apps.AppIONull.String():   apps.AppIONull,
+		apps.AppIOStream.String(): apps.AppIOStream,
+		apps.AppIOTTY.String():    apps.AppIOTTY,
+	}
+	mode, ok := allowedOutModes[s]
+	if !ok {
+		return fmt.Errorf("invalid stdout mode %q", s)
+	}
+	app.Stdout = mode
+	return nil
+}
+
+func (au *appStdout) String() string {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return ""
+	}
+	return app.Stdout.String()
+}
+
+func (au *appStdout) Type() string {
+	return "appStdout"
+}
+
+// `--stderr=mode` flag
+type appStderr apps.Apps
+
+func (au *appStderr) Set(s string) error {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return fmt.Errorf("--stderr must follow an application")
+	}
+	allowedErrModes := map[string]apps.AppIO{
+		apps.AppIOLog.String():    apps.AppIOLog,
+		apps.AppIONull.String():   apps.AppIONull,
+		apps.AppIOStream.String(): apps.AppIOStream,
+		apps.AppIOTTY.String():    apps.AppIOTTY,
+	}
+	mode, ok := allowedErrModes[s]
+	if !ok {
+		return fmt.Errorf("invalid stderr mode %q", s)
+	}
+	app.Stderr = mode
+	return nil
+}
+
+func (au *appStderr) String() string {
+	app := (*apps.Apps)(au).Last()
+	if app == nil {
+		return ""
+	}
+	return app.Stderr.String()
+}
+
+func (au *appStderr) Type() string {
+	return "appStderr"
+}
