@@ -15,24 +15,20 @@
 package main
 
 import (
-	"runtime"
-
 	"github.com/appc/spec/schema/types"
-	"github.com/coreos/rkt/common/apps"
-	"github.com/coreos/rkt/rkt/image"
-	"github.com/coreos/rkt/store/imagestore"
-	"github.com/coreos/rkt/store/treestore"
+	"github.com/rkt/rkt/common"
+	"github.com/rkt/rkt/common/apps"
+	"github.com/rkt/rkt/rkt/image"
+	"github.com/rkt/rkt/store/imagestore"
+	"github.com/rkt/rkt/store/treestore"
 
 	"github.com/spf13/cobra"
 )
 
-const (
-	defaultOS   = runtime.GOOS
-	defaultArch = runtime.GOARCH
-)
-
 var (
-	cmdFetch = &cobra.Command{
+	defaultOS   = common.GetOS()
+	defaultArch = common.GetArch()
+	cmdFetch    = &cobra.Command{
 		Use:   "fetch IMAGE_URL...",
 		Short: "Fetch image(s) and store them in the local store",
 		Long: `Locates and downloads remote ACIs and their attached signatures.
@@ -42,6 +38,9 @@ again.`,
 		Run: runWrapper(runFetch),
 	}
 	flagFullHash bool
+	// We can't have different defaults for a given flag variable shared across
+	// subcommands, so we can't use pullPolicyUpdate here
+	flagPullPolicyDefaultUpdate string
 )
 
 func init() {
@@ -52,8 +51,11 @@ func init() {
 
 	cmdFetch.Flags().Var((*appAsc)(&rktApps), "signature", "local signature file to use in validating the preceding image")
 	cmdFetch.Flags().BoolVar(&flagStoreOnly, "store-only", false, "use only available images in the store (do not discover or download from remote URLs)")
+	cmdFetch.Flags().MarkDeprecated("store-only", "please use --pull-policy=never")
 	cmdFetch.Flags().BoolVar(&flagNoStore, "no-store", false, "fetch images ignoring the local store")
+	cmdFetch.Flags().MarkDeprecated("no-store", "please use --pull-policy=update")
 	cmdFetch.Flags().BoolVar(&flagFullHash, "full", false, "print the full image hash after fetching")
+	cmdFetch.Flags().StringVar(&flagPullPolicyDefaultUpdate, "pull-policy", image.PullPolicyUpdate, "when to pull an image")
 
 	cmdRkt.AddCommand(cmdFetch)
 
@@ -74,10 +76,20 @@ func runFetch(cmd *cobra.Command, args []string) (exit int) {
 		return 254
 	}
 
+	// flagPullPolicy defaults to new regardless of subcommand, so we use a
+	// different variable for the flag on fetch and then set it here
+	flagPullPolicy = flagPullPolicyDefaultUpdate
+
 	if flagStoreOnly && flagNoStore {
 		stderr.Print("both --store-only and --no-store specified")
 		return 254
 	}
+	if flagStoreOnly {
+		flagPullPolicy = image.PullPolicyNever
+	}
+	if flagNoStore {
+		flagPullPolicy = image.PullPolicyUpdate
+	}
 
 	s, err := imagestore.NewStore(storeDir())
 	if err != nil {
@@ -107,9 +119,8 @@ func runFetch(cmd *cobra.Command, args []string) (exit int) {
 		Debug:              globalFlags.Debug,
 		TrustKeysFromHTTPS: globalFlags.TrustKeysFromHTTPS,
 
-		StoreOnly: flagStoreOnly,
-		NoStore:   flagNoStore,
-		WithDeps:  true,
+		PullPolicy: flagPullPolicy,
+		WithDeps:   true,
 	}
 
 	err = ft.FetchImages(&rktApps)
