@@ -20,14 +20,13 @@ import (
 	"fmt"
 	"net/url"
 	"os"
-	"runtime"
 
-	"github.com/coreos/rkt/common"
-	"github.com/coreos/rkt/common/apps"
-	dist "github.com/coreos/rkt/pkg/distribution"
-	"github.com/coreos/rkt/stage0"
-	"github.com/coreos/rkt/store/imagestore"
 	"github.com/hashicorp/errwrap"
+	"github.com/rkt/rkt/common"
+	"github.com/rkt/rkt/common/apps"
+	dist "github.com/rkt/rkt/pkg/distribution"
+	"github.com/rkt/rkt/stage0"
+	"github.com/rkt/rkt/store/imagestore"
 
 	"github.com/appc/spec/discovery"
 	"github.com/appc/spec/schema/types"
@@ -233,7 +232,7 @@ func (f *Fetcher) fetchSingleImageByDockerURL(d *dist.Docker) (string, error) {
 }
 
 func (f *Fetcher) maybeCheckRemoteFromStore(rem *imagestore.Remote) string {
-	if f.NoStore || rem == nil {
+	if f.PullPolicy == PullPolicyUpdate || rem == nil {
 		return ""
 	}
 	diag.Printf("using image from local store for url %s", rem.ACIURL)
@@ -241,7 +240,7 @@ func (f *Fetcher) maybeCheckRemoteFromStore(rem *imagestore.Remote) string {
 }
 
 func (f *Fetcher) maybeFetchHTTPURLFromRemote(rem *imagestore.Remote, u *url.URL, a *asc) (string, error) {
-	if !f.StoreOnly {
+	if f.PullPolicy != PullPolicyNever {
 		diag.Printf("remote fetching from URL %q", u.String())
 		hf := &httpFetcher{
 			InsecureFlags: f.InsecureFlags,
@@ -257,7 +256,7 @@ func (f *Fetcher) maybeFetchHTTPURLFromRemote(rem *imagestore.Remote, u *url.URL
 }
 
 func (f *Fetcher) maybeFetchDockerURLFromRemote(u *url.URL) (string, error) {
-	if !f.StoreOnly {
+	if f.PullPolicy != PullPolicyNever {
 		diag.Printf("remote fetching from URL %q", u.String())
 		df := &dockerFetcher{
 			InsecureFlags: f.InsecureFlags,
@@ -283,14 +282,14 @@ func (f *Fetcher) fetchSingleImageByPath(path string, a *asc) (string, error) {
 
 // TODO(sgotti) I'm not sure setting default os and arch also for image
 // dependencies is correct since it may break noarch dependencies. Reference:
-// https://github.com/coreos/rkt/pull/2317
+// https://github.com/rkt/rkt/pull/2317
 func (db *distBundle) setAppDefaults() error {
 	app := db.dist.(*dist.Appc).App()
 	if _, ok := app.Labels["arch"]; !ok {
-		app.Labels["arch"] = runtime.GOARCH
+		app.Labels["arch"] = common.GetArch()
 	}
 	if _, ok := app.Labels["os"]; !ok {
-		app.Labels["os"] = runtime.GOOS
+		app.Labels["os"] = common.GetOS()
 	}
 	if err := types.IsValidOSArch(app.Labels, stage0.ValidOSArch); err != nil {
 		return errwrap.Wrap(fmt.Errorf("invalid Appc distribution %q", db.image), err)
@@ -313,7 +312,7 @@ func (f *Fetcher) fetchSingleImageByName(db *distBundle, a *asc) (string, error)
 }
 
 func (f *Fetcher) maybeCheckStoreForApp(db *distBundle) (string, error) {
-	if !f.NoStore {
+	if f.PullPolicy != PullPolicyUpdate {
 		key, err := f.getStoreKeyFromApp(db)
 		if err == nil {
 			diag.Printf("using image from local store for image name %s", db.image)
@@ -348,7 +347,7 @@ func (f *Fetcher) getStoreKeyFromApp(db *distBundle) (string, error) {
 }
 
 func (f *Fetcher) maybeFetchImageFromRemote(db *distBundle, a *asc) (string, error) {
-	if !f.StoreOnly {
+	if f.PullPolicy != PullPolicyNever {
 		app := db.dist.(*dist.Appc).App()
 		nf := &nameFetcher{
 			InsecureFlags:      f.InsecureFlags,
