@@ -21,9 +21,9 @@ import (
 	"net/url"
 	"os"
 
-	"github.com/coreos/rkt/rkt/config"
-	"github.com/coreos/rkt/store"
 	"github.com/hashicorp/errwrap"
+	"github.com/rkt/rkt/rkt/config"
+	"github.com/rkt/rkt/store/imagestore"
 )
 
 // httpOps is a kind of facade around a downloader and a
@@ -32,7 +32,7 @@ import (
 // remote fetcher for asc.
 type httpOps struct {
 	InsecureSkipTLSVerify bool
-	S                     *store.Store
+	S                     *imagestore.Store
 	Headers               map[string]config.Headerer
 	Debug                 bool
 }
@@ -42,14 +42,14 @@ type httpOps struct {
 // this function will return true and no error and no file.
 func (o *httpOps) DownloadSignature(a *asc) (readSeekCloser, bool, error) {
 	ensureLogger(o.Debug)
-	log.Printf("downloading signature from %v", a.Location)
+	diag.Printf("downloading signature from %v", a.Location)
 	ascFile, err := a.Get()
 	if err == nil {
 		return ascFile, false, nil
 	}
 	if _, ok := err.(*statusAcceptedError); ok {
 		log.Printf("server requested deferring the signature download")
-		return nil, true, nil
+		return NopReadSeekCloser(nil), true, nil
 	}
 	return nil, false, errwrap.Wrap(errors.New("error downloading the signature file"), err)
 }
@@ -86,24 +86,34 @@ func (o *httpOps) DownloadImage(u *url.URL) (readSeekCloser, *cacheData, error)
 // DownloadImageWithETag might download an image or tell you to use
 // the cached image. In the latter case the returned file will be nil.
 func (o *httpOps) DownloadImageWithETag(u *url.URL, etag string) (readSeekCloser, *cacheData, error) {
+	var aciFile *removeOnClose // closed on error
+	var errClose error         // error signaling to close aciFile
+
 	ensureLogger(o.Debug)
 	aciFile, err := getTmpROC(o.S, u.String())
 	if err != nil {
 		return nil, nil, err
 	}
-	defer func() { maybeClose(aciFile) }()
+
+	defer func() {
+		if errClose != nil {
+			aciFile.Close()
+		}
+	}()
 
 	session := o.getSession(u, aciFile.File, "ACI", etag)
 	dl := o.getDownloader(session)
-	if err := dl.Download(u, aciFile.File); err != nil {
-		return nil, nil, errwrap.Wrap(errors.New("error downloading ACI"), err)
+	errClose = dl.Download(u, aciFile.File)
+	if errClose != nil {
+		return nil, nil, errwrap.Wrap(errors.New("error downloading ACI"), errClose)
 	}
+
 	if session.Cd.UseCached {
-		return nil, session.Cd, nil
+		aciFile.Close()
+		return NopReadSeekCloser(nil), session.Cd, nil
 	}
-	retAciFile := aciFile
-	aciFile = nil
-	return retAciFile, session.Cd, nil
+
+	return aciFile, session.Cd, nil
 }
 
 // AscRemoteFetcher provides a remoteAscFetcher for asc.
