@@ -41,13 +41,13 @@ import (
 	"github.com/appc/spec/schema/types"
 	cnitypes "github.com/containernetworking/cni/pkg/types"
 	"github.com/hashicorp/errwrap"
+	"github.com/opencontainers/selinux/go-selinux/label"
 	"github.com/rkt/rkt/common"
 	"github.com/rkt/rkt/common/apps"
 	commonnet "github.com/rkt/rkt/common/networking"
 	"github.com/rkt/rkt/common/overlay"
 	"github.com/rkt/rkt/pkg/aci"
 	"github.com/rkt/rkt/pkg/fileutil"
-	"github.com/rkt/rkt/pkg/label"
 	"github.com/rkt/rkt/pkg/sys"
 	"github.com/rkt/rkt/pkg/tpm"
 	"github.com/rkt/rkt/pkg/user"
