@@ -27,24 +27,24 @@ import (
 	"regexp"
 	"strconv"
 	"strings"
+	"syscall"
 
-	"github.com/coreos/rkt/pkg/acl"
-	stage1commontypes "github.com/coreos/rkt/stage1/common/types"
+	"github.com/rkt/rkt/pkg/acl"
+	stage1commontypes "github.com/rkt/rkt/stage1/common/types"
 
 	"github.com/appc/spec/schema"
 	"github.com/appc/spec/schema/types"
 	"github.com/coreos/go-systemd/unit"
 	"github.com/hashicorp/errwrap"
 
-	"github.com/coreos/rkt/common"
-	"github.com/coreos/rkt/pkg/fileutil"
-	"github.com/coreos/rkt/pkg/user"
+	"github.com/rkt/rkt/common"
+	"github.com/rkt/rkt/pkg/fileutil"
+	"github.com/rkt/rkt/pkg/user"
 )
 
 const (
 	// FlavorFile names the file storing the pod's flavor
-	FlavorFile    = "flavor"
-	SharedVolPerm = os.FileMode(0755)
+	FlavorFile = "flavor"
 )
 
 // execEscape uses Golang's string quoting for ", \, \n, and regex for special cases
@@ -303,7 +303,7 @@ func FindBinPath(p *stage1commontypes.Pod, ra *schema.RuntimeApp) (string, error
 // node, we create a symlink to its target in "/rkt/volumes". Later,
 // prepare-app will copy those to "/dev/.rkt/" so that's what we use in the
 // DeviceAllow= line.
-func generateDeviceAllows(root string, appName types.ACName, mountPoints []types.MountPoint, mounts []mountWrapper, uidRange *user.UidRange) ([]string, error) {
+func generateDeviceAllows(root string, appName types.ACName, mountPoints []types.MountPoint, mounts []Mount, uidRange *user.UidRange) ([]string, error) {
 	var devAllow []string
 
 	rktVolumeLinksPath := filepath.Join(root, "rkt", "volumes")
@@ -357,7 +357,7 @@ func supportsNotify(p *stage1commontypes.Pod, appName string) bool {
 	return false
 }
 
-// parseUserGroup parses the User and Group fields of an App and returns its
+// ParseUserGroup parses the User and Group fields of an App and returns its
 // UID and GID.
 // The User and Group fields accept several formats:
 //   1. the hardcoded string "root"
@@ -365,7 +365,7 @@ func supportsNotify(p *stage1commontypes.Pod, appName string) bool {
 //   3. a number
 //   4. a name in reference to /etc/{group,passwd} in the image
 // See https://github.com/appc/spec/blob/master/spec/aci.md#image-manifest-schema
-func parseUserGroup(p *stage1commontypes.Pod, ra *schema.RuntimeApp) (int, int, error) {
+func ParseUserGroup(p *stage1commontypes.Pod, ra *schema.RuntimeApp) (int, int, error) {
 	var uidResolver, gidResolver user.Resolver
 	var uid, gid int
 	var err error
@@ -403,7 +403,25 @@ func parseUserGroup(p *stage1commontypes.Pod, ra *schema.RuntimeApp) (int, int,
 	}
 
 	if _, gid, err = gidResolver.IDs(); err != nil {
-		return -1, -1, errwrap.Wrap(fmt.Errorf("failed to configure group %q", ra.App.Group), err)
+		// If we can't resolve the GID, it might be an image converted from
+		// docker.
+		//
+		// Docker uses the UID as GID if you only specify the "user". In that
+		// case, docker2aci sets the group name to the user name because the
+		// appc spec requires both user and group to be set. This will fail
+		// because that group name won't be found in /etc/group. Let's detect
+		// if the image was converted from docker and set the GID to the UID in
+		// that case.
+		//
+		// We only do this if the group in RuntimeApp is the same as the one in
+		// the image, otherwise we trust that the user knows what they're
+		// doing.
+		img := p.Images[ra.Name.String()]
+		if ConvertedFromDocker(img) && img.App.User == img.App.Group && ra.App.Group == img.App.Group {
+			gid = uid
+		} else {
+			return -1, -1, errwrap.Wrap(fmt.Errorf("failed to configure group %q", ra.App.Group), err)
+		}
 	}
 
 	return uid, gid, nil
@@ -413,48 +431,27 @@ func parseUserGroup(p *stage1commontypes.Pod, ra *schema.RuntimeApp) (int, int,
 // It returns the actual path relative to the app rootfs for the given path.
 // This is needed for absolute symlinks - we are in a different rootfs.
 func EvaluateSymlinksInsideApp(appRootfs, path string) (string, error) {
-	link := appRootfs
-
-	paths := strings.Split(path, "/")
-	for i, p := range paths {
-		next := filepath.Join(link, p)
-
-		if !strings.HasPrefix(next, appRootfs) {
-			return "", fmt.Errorf("path escapes app's root: %q", path)
-		}
-
-		fi, err := os.Lstat(next)
-		if err != nil {
-			if os.IsNotExist(err) {
-				link = filepath.Join(append([]string{link}, paths[i:]...)...)
-				break
-			}
-			return "", err
-		}
-
-		if fi.Mode()&os.ModeType != os.ModeSymlink {
-			link = filepath.Join(link, p)
-			continue
-		}
-
-		// Evaluate the symlink.
-		target, err := os.Readlink(next)
-		if err != nil {
-			return "", err
-		}
-
-		if filepath.IsAbs(target) {
-			link = filepath.Join(appRootfs, target)
-		} else {
-			link = filepath.Join(link, target)
-		}
-
-		if !strings.HasPrefix(link, appRootfs) {
-			return "", fmt.Errorf("symlink %q escapes app's root with value %q", next, target)
-		}
+	chroot, err := newChroot(appRootfs)
+	if err != nil {
+		return "", errwrap.Wrapf(fmt.Sprintf("chroot to %q failed", appRootfs), err)
 	}
 
-	return strings.TrimPrefix(link, appRootfs), nil
+	target, err := fileutil.EvalSymlinksAlways(path)
+	if err != nil {
+		return "", errwrap.Wrapf(fmt.Sprintf("evaluating symlinks of %q failed", path), err)
+	}
+
+	// EvalSymlinksAlways might return a relative path
+	abs, err := filepath.Abs(target)
+	if err != nil {
+		return "", errwrap.Wrapf(fmt.Sprintf("failed to get absolute representation of %q", target), err)
+	}
+
+	if err := chroot.escape(); err != nil {
+		return "", errwrap.Wrapf(fmt.Sprintf("escaping chroot %q failed", appRootfs), err)
+	}
+
+	return abs, nil
 }
 
 // appToNspawnArgs transforms the given app manifest, with the given associated
@@ -464,12 +461,9 @@ func appToNspawnArgs(p *stage1commontypes.Pod, ra *schema.RuntimeApp) ([]string,
 	appName := ra.Name
 	app := ra.App
 
-	sharedVolPath := common.SharedVolumesPath(p.Root)
-	if err := os.MkdirAll(sharedVolPath, SharedVolPerm); err != nil {
-		return nil, errwrap.Wrap(errors.New("could not create shared volumes directory"), err)
-	}
-	if err := os.Chmod(sharedVolPath, SharedVolPerm); err != nil {
-		return nil, errwrap.Wrap(fmt.Errorf("could not change permissions of %q", sharedVolPath), err)
+	sharedVolPath, err := common.CreateSharedVolumesPath(p.Root)
+	if err != nil {
+		return nil, err
 	}
 
 	vols := make(map[types.ACName]types.Volume)
@@ -483,7 +477,6 @@ func appToNspawnArgs(p *stage1commontypes.Pod, ra *schema.RuntimeApp) ([]string,
 		return nil, errwrap.Wrap(fmt.Errorf("could not generate app %q mounts", appName), err)
 	}
 	for _, m := range mounts {
-
 		shPath := filepath.Join(sharedVolPath, m.Volume.Name.String())
 
 		absRoot, err := filepath.Abs(p.Root) // Absolute path to the pod's rootfs.
@@ -731,55 +724,60 @@ func getAppNoNewPrivileges(isolators types.Isolators) bool {
 	return false
 }
 
-// protectKernelTunables restricts access to some security-sensitive paths under
-// /proc and /sys. Entries are either hidden or just made read-only to app.
-// This protection is enabled by default.
-func protectKernelTunables(opts []*unit.UnitOption, appName types.ACName, systemdVersion int) []*unit.UnitOption {
-	roPaths := []string{
-		"/proc/bus/",
-		"/proc/sys/kernel/core_pattern",
-		"/proc/sys/kernel/modprobe",
-		"/proc/sys/vm/panic_on_oom",
-		"/proc/sysrq-trigger",
-		"/sys/block/",
-		"/sys/bus/",
-		"/sys/class/",
-		"/sys/dev/",
-		"/sys/devices/",
-		"/sys/kernel/",
-	}
-	hiddenDirs := []string{
-		"/sys/firmware/",
-		"/sys/fs/",
-		"/sys/hypervisor/",
-		"/sys/module/",
-		"/sys/power/",
-	}
-	hiddenPaths := []string{
-		"/proc/config.gz",
-		"/proc/kallsyms",
-		"/proc/sched_debug",
-		"/proc/kcore",
-		"/proc/kmem",
-		"/proc/mem",
-	}
-
-	// Paths prefixed with "-" are ignored if they do not exist:
-	// https://www.freedesktop.org/software/systemd/man/systemd.exec.html#ReadWriteDirectories=
-	for _, p := range roPaths {
-		opts = append(opts, unit.NewUnitOption("Service", "ReadOnlyDirectories", fmt.Sprintf("-%s", filepath.Join(common.RelAppRootfsPath(appName), p))))
-	}
-	for _, p := range hiddenDirs {
-		opts = append(opts, unit.NewUnitOption("Service", "InaccessibleDirectories", fmt.Sprintf("-%s", filepath.Join(common.RelAppRootfsPath(appName), p))))
-	}
-	if systemdVersion >= 231 {
-		for _, p := range hiddenPaths {
-			opts = append(opts, unit.NewUnitOption("Service", "InaccessiblePaths", fmt.Sprintf("-%s", filepath.Join(common.RelAppRootfsPath(appName), p))))
-		}
-	}
-	if systemdVersion >= 233 {
-		opts = append(opts, unit.NewUnitOption("Service", "ProtectKernelTunables", "true"))
-	}
-
-	return opts
+// chroot is the struct that represents a chroot environment
+type chroot struct {
+	wd   string   // the working directory in the outer root
+	root *os.File // the outer root directory
+}
+
+// newChroot creates a new chroot environment for the given path.
+// Unless the caller calls Escape() all system operations will be invoked in that environment.
+// It stores the working directory at the point it was invoked.
+func newChroot(path string) (*chroot, error) {
+	var err error
+	var c chroot
+
+	c.wd, err = os.Getwd()
+	if err != nil {
+		return nil, errwrap.Wrapf("getwd before chroot failed", err)
+	}
+
+	c.root, err = os.Open("/")
+	if err != nil {
+		return nil, errwrap.Wrapf("error opening outer root", err)
+	}
+
+	if err := syscall.Chroot(path); err != nil {
+		return nil, errwrap.Wrapf("chroot to "+path+" failed", err)
+	}
+
+	if err := os.Chdir("/"); err != nil {
+		return nil, errwrap.Wrapf("chdir to \"/\" failed", err)
+	}
+
+	return &c, nil
+}
+
+// Escape escapes the chroot environment changing back to the original working directory where newChroot was invoked.
+func (c *chroot) escape() error {
+	// change directory to outer root and close it
+	if err := syscall.Fchdir(int(c.root.Fd())); err != nil {
+		return errwrap.Wrapf("changing directory to outer root failed", err)
+	}
+
+	if err := c.root.Close(); err != nil {
+		return errwrap.Wrapf("closing outer root failed", err)
+	}
+
+	// chroot to current directory aka "." being the outer root
+	if err := syscall.Chroot("."); err != nil {
+		return errwrap.Wrapf("chroot to current directory failed", err)
+	}
+
+	// chdir into previous working directory
+	if err := os.Chdir(c.wd); err != nil {
+		return errwrap.Wrapf("chdir to working directory failed", err)
+	}
+
+	return nil
 }
