@@ -328,6 +328,16 @@ func (uw *UnitWriter) SetupAppIO(p *stage1commontypes.Pod, ra *schema.RuntimeApp
 			if ok {
 				file.WriteString(fmt.Sprintf("STAGE1_LOGMODE=%s\n", logMode))
 			}
+			switch logMode {
+			case "k8s-plain":
+				kubernetesLogPath, ok := ra.Annotations.Get("coreos.com/rkt/experiment/kubernetes-log-path")
+				if !ok {
+					uw.err = fmt.Errorf("kubernetes-log-path annotation needs to be specified when k8s-plain logging mode is used")
+					return nil
+				}
+				file.WriteString(fmt.Sprintf("KUBERNETES_LOG_PATH=%s\n", kubernetesLogPath))
+			}
+
 		} else if needsTTYMux {
 			// tty mode brings in a `ttymux@.service` after-dependency (it needs to create the TTY first)
 			opts = append(opts, unit.NewUnitOption("Service", "TTYPath", filepath.Join("/rkt/iottymux", ra.Name.String(), "stage2-pts")))
@@ -338,10 +348,10 @@ func (uw *UnitWriter) SetupAppIO(p *stage1commontypes.Pod, ra *schema.RuntimeApp
 	return opts
 }
 
-// UnitWriter is the type that writes systemd units preserving the first previously occured error.
+// UnitWriter is the type that writes systemd units preserving the first previously occurred error.
 // Any method of this type can be invoked multiple times without error checking.
 // If a previous invocation generated an error, any invoked method will be skipped.
-// If an error occured during method invocations, it can be retrieved using Error().
+// If an error occurred during method invocations, it can be retrieved using Error().
 type UnitWriter struct {
 	err error
 	p   *stage1commontypes.Pod
@@ -353,7 +363,7 @@ func NewUnitWriter(p *stage1commontypes.Pod) *UnitWriter {
 }
 
 // WriteUnit writes a systemd unit in the given path with the given unit options
-// if no previous error occured.
+// if no previous error occurred.
 func (uw *UnitWriter) WriteUnit(path string, errmsg string, opts ...*unit.UnitOption) {
 	if uw.err != nil {
 		return
@@ -377,7 +387,7 @@ func (uw *UnitWriter) WriteUnit(path string, errmsg string, opts ...*unit.UnitOp
 }
 
 // writeShutdownService writes a shutdown.service unit with the given unit options
-// if no previous error occured.
+// if no previous error occurred.
 // exec specifies how systemctl should be invoked, i.e. ExecStart, or ExecStop.
 func (uw *UnitWriter) writeShutdownService(exec string, opts ...*unit.UnitOption) {
 	if uw.err != nil {
@@ -439,7 +449,7 @@ func (uw *UnitWriter) Activate(unit, wantPath string) {
 	}
 }
 
-// error returns the first error that occured during write* invocations.
+// error returns the first error that occurred during write* invocations.
 func (uw *UnitWriter) Error() error {
 	return uw.err
 }
@@ -541,6 +551,7 @@ func (uw *UnitWriter) appSystemdUnit(pa *preparedApp, binPath string, opts []*un
 		unit.NewUnitOption("Service", "EnvironmentFile", RelEnvFilePath(appName)),
 		unit.NewUnitOption("Service", "User", strconv.Itoa(int(pa.uid))),
 		unit.NewUnitOption("Service", "Group", strconv.Itoa(int(pa.gid))),
+		unit.NewUnitOption("Service", "PermissionsStartOnly", "true"),
 		unit.NewUnitOption("Unit", "Requires", InstantiatedPrepareAppUnitName(ra.Name)),
 		unit.NewUnitOption("Unit", "After", InstantiatedPrepareAppUnitName(ra.Name)),
 	)
