@@ -23,8 +23,8 @@ import (
 	"os"
 	"syscall"
 
-	rktlog "github.com/coreos/rkt/pkg/log"
-	"github.com/coreos/rkt/stage1/common/ssh"
+	rktlog "github.com/rkt/rkt/pkg/log"
+	"github.com/rkt/rkt/stage1/common/ssh"
 )
 
 var (
