@@ -28,9 +28,9 @@ function ciSkip {
     exit 0
 }
 
-# Finds the branching point of two commits. 
-# For example, let B and D be two commits, and their ancestry graph as A -> B, A -> C -> D. 
-# Given commits B and D, it returns A. 
+# Finds the branching point of two commits.
+# For example, let B and D be two commits, and their ancestry graph as A -> B, A -> C -> D.
+# Given commits B and D, it returns A.
 function getBranchingPoint {
     diff --old-line-format='' --new-line-format='' \
         <(git rev-list --first-parent "${1:-$1}") \
@@ -51,7 +51,7 @@ function semaphoreCIConfiguration {
     if [ -f /opt/change-go-version.sh ]; then
         . /opt/change-go-version.sh
         change-go-version 1.7
-        
+
 	# systemd v229 doesn't build on gcc-4.8, set the compiler to gcc-5
         export CC=gcc-5
     fi
@@ -74,7 +74,7 @@ function checkFlavorValue {
 
 # Parse user provided parameters
 function parseParameters {
-    while getopts "f:s:r:cxujd" option; do
+    while getopts "f:s:r:cxujdv" option; do
         case ${option} in
         f)
             RKT_STAGE1_USR_FROM="${OPTARG}"
@@ -111,6 +111,9 @@ function parseParameters {
         d)
             DIRTYBUILD=true
             ;;
+        v)
+            VERBOSITY="V=3"
+            ;;
         \?)
             set -
             echo "Invalid parameter -${OPTARG}"
@@ -167,14 +170,14 @@ function build {
 
     CORES=$(grep -c ^processor /proc/cpuinfo)
     echo "Running make with ${CORES} threads"
-    make "-j${CORES}"
+    make "-j${CORES}" ${VERBOSITY}
     make manpages bash-completion
 
     if [[ ${PRECLEANUP} == true ]]; then
         rm -rf "${BUILD_DIR}/tmp/usr_from_${RKT_STAGE1_USR_FROM}"
     fi
     if [[ ${JUSTBUILD} != true ]]; then
-        make check
+        make ${VERBOSITY} check
         make "-j${CORES}" clean
     fi
 }
@@ -230,6 +233,7 @@ function usage {
     echo -e "-s\tSystemd version"
     echo -e "-r\tSystemd revision"
     echo -e "-u\tShow this message"
+    echo -e "-v\tRun make with verbose flag"
     echo -e "-x\tUse with '-c' to force cleanup on non-CI systems"
 }
 
