@@ -21,10 +21,8 @@ import (
 	"encoding/json"
 	"fmt"
 	"os"
-	"os/user"
 	"path/filepath"
 	"reflect"
-	"strconv"
 	"strings"
 	"syscall"
 	"testing"
@@ -33,41 +31,33 @@ import (
 	"github.com/appc/spec/schema"
 	"github.com/appc/spec/schema/types"
 	"github.com/coreos/gexpect"
-	"github.com/coreos/rkt/api/v1alpha"
-	"github.com/coreos/rkt/common"
-	"github.com/coreos/rkt/tests/testutils"
+	"github.com/rkt/rkt/api/v1alpha"
+	"github.com/rkt/rkt/common"
+	"github.com/rkt/rkt/tests/testutils"
 	"golang.org/x/net/context"
 )
 
 func startAPIService(t *testing.T, ctx *testutils.RktRunCtx) *gexpect.ExpectSubprocess {
-	noUidGid := false
-	gid, err := common.LookupGid(common.RktGroup)
+	noRktGid := false
+	rktGid, err := common.LookupGid(common.RktGroup)
 	if err != nil {
 		t.Logf("no %q group, will run api service with root, ONLY DO THIS FOR TESTING!", common.RktGroup)
-		noUidGid = true
+		noRktGid = true
 	} else {
 		if err := ctx.SetupDataDir(); err != nil {
 			t.Fatalf("failed to setup data directory: %v", err)
 		}
 	}
 
-	u, err := user.Lookup("nobody")
-	if err != nil {
-		t.Logf(`no "nobody" user, will run api service with root, ONLY DO THIS FOR TESTING!`)
-		noUidGid = true
-	}
-	uid, err := strconv.Atoi(u.Uid)
-	if err != nil {
-		t.Fatalf(`failed to parse "nobody" UID: %v`, err)
-	}
+	uid, _ := ctx.GetUidGidRktBinOwnerNotRoot()
 
 	t.Logf("Running rkt api service")
 	apisvcCmd := fmt.Sprintf("%s api-service", ctx.Cmd())
 
-	if noUidGid {
+	if noRktGid {
 		return startRktAndCheckOutput(t, apisvcCmd, "API service running")
 	}
-	return startRktAsUidGidAndCheckOutput(t, apisvcCmd, "API service running", false, uid, gid)
+	return startRktAsUidGidAndCheckOutput(t, apisvcCmd, "API service running", false, uid, rktGid)
 }
 
 func stopAPIService(t *testing.T, svc *gexpect.ExpectSubprocess) {
