@@ -18,10 +18,11 @@ package main
 
 import (
 	"fmt"
+	"io/ioutil"
 	"os"
 	"testing"
 
-	"github.com/coreos/rkt/tests/testutils"
+	"github.com/rkt/rkt/tests/testutils"
 )
 
 // TestCatManifest tests 'rkt cat-manifest', it will:
@@ -41,30 +42,54 @@ func TestCatManifest(t *testing.T) {
 	cmd := fmt.Sprintf("%s --insecure-options=image prepare %s", ctx.Cmd(), imgID.path)
 	podUuid := runRktAndGetUUID(t, cmd)
 
-	tmpDir := createTempDirOrPanic(imgName)
+	tmpDir := mustTempDir(imgName)
 	defer os.RemoveAll(tmpDir)
 
 	tests := []struct {
-		uuid  string
-		match string
+		uuid     string
+		match    string
+		uuidFile bool
 	}{
 		{
 			podUuid,
 			imgName,
+			false,
 		},
 		{
 			podUuid,
 			imageHash[:20],
+			false,
 		},
 		{
 			"1234567890abcdef",
 			"no matches found for",
+			false,
+		},
+		{
+			"",
+			imageHash[:20],
+			true,
 		},
 	}
 
 	for i, tt := range tests {
-		runCmd := fmt.Sprintf("%s cat-manifest --pretty-print=false %s", ctx.Cmd(), tt.uuid)
-		t.Logf("Running test #%d", i)
-		runRktAndCheckRegexOutput(t, runCmd, tt.match)
+		if tt.uuidFile == true {
+			podUUID := runRktAndGetUUID(t, cmd)
+			uuidFile, err := ioutil.TempFile(tmpDir, "uuid-file")
+			if err != nil {
+				panic(fmt.Sprintf("Cannot create uuid-file: %v", err))
+			}
+			uuidFilePath := uuidFile.Name()
+			if err := ioutil.WriteFile(uuidFilePath, []byte(podUUID), 0600); err != nil {
+				panic(fmt.Sprintf("Cannot write pod UUID to uuid-file: %v", err))
+			}
+			runCmd := fmt.Sprintf("%s cat-manifest --uuid-file=%s --pretty-print=false %s", ctx.Cmd(), uuidFilePath)
+			t.Logf("Running test #%d", i)
+			runRktAndCheckRegexOutput(t, runCmd, tt.match)
+		} else {
+			runCmd := fmt.Sprintf("%s cat-manifest --pretty-print=false %s", ctx.Cmd(), tt.uuid)
+			t.Logf("Running test #%d", i)
+			runRktAndCheckRegexOutput(t, runCmd, tt.match)
+		}
 	}
 }
