@@ -21,57 +21,26 @@ import (
 	"io/ioutil"
 	"os"
 	"path/filepath"
-	"strings"
 	"testing"
 
-	"github.com/coreos/rkt/common"
-	"github.com/coreos/rkt/tests/testutils"
-	taas "github.com/coreos/rkt/tests/testutils/aci-server"
+	"github.com/rkt/rkt/common"
+	"github.com/rkt/rkt/pkg/aci/acitest"
+	"github.com/rkt/rkt/tests/testutils"
+	taas "github.com/rkt/rkt/tests/testutils/aci-server"
+
+	"github.com/appc/spec/schema"
+	"github.com/appc/spec/schema/types"
 )
 
 const (
-	manifestDepsTemplate = `
-{
-   "acKind" : "ImageManifest",
-   "acVersion" : "0.8.9",
-   "dependencies" : [
-      DEPENDENCIES
-   ],
-   "labels" : [
-      {
-         "name" : "version",
-         "value" : "VERSION"
-      },
-      {
-         "name" : "arch",
-         "value" : "amd64"
-      },
-      {
-         "value" : "linux",
-         "name" : "os"
-      }
-   ],
-   "app" : {
-      "user" : "0",
-      "exec" : [
-         "/inspect", "--print-msg=HelloDependencies"
-      ],
-      "workingDirectory" : "/",
-      "group" : "0",
-      "environment" : [
-      ]
-   },
-   "name" : "IMG_NAME"
-}
-`
+	// topImage defines the name of the top-level image.
+	topImage = "localhost/image-a"
 )
 
-var topImage string = "localhost/image-a"
-
 type testImage struct {
 	shortName string
 	imageName string
-	deps      string
+	deps      types.Dependencies
 	version   string
 	prefetch  bool
 
@@ -80,17 +49,35 @@ type testImage struct {
 }
 
 func generateComplexDependencyTree(t *testing.T, ctx *testutils.RktRunCtx) (map[string]string, []testImage) {
-	tmpDir := createTempDirOrPanic("rkt-TestImageDeps-")
+	// manifest specifies the generic configuration
+	// of the image manifest used in dependencies tests.
+	manifest := schema.ImageManifest{
+		App: &types.App{
+			Exec: types.Exec{
+				"/inspect",
+				"--print-msg=HelloDependencies",
+			},
+			User: "0", Group: "0",
+			WorkingDirectory: "/",
+		},
+		Labels: types.Labels{
+			{"arch", common.GetArch()},
+			{"os", common.GetOS()},
+		},
+	}
+
+	tmpDir := mustTempDir("rkt-TestImageDeps-")
 	defer os.RemoveAll(tmpDir)
 
 	baseImage := getInspectImagePath()
-	if _, err := importImageAndFetchHash(t, ctx, "", baseImage); err != nil {
+	_, err := importImageAndFetchHash(t, ctx, "", baseImage)
+	if err != nil {
 		t.Fatalf("%v", err)
 	}
 	emptyImage := getEmptyImagePath()
 	fileSet := make(map[string]string)
 
-	// Scenario from https://github.com/coreos/rkt/issues/1752#issue-117121841
+	// Scenario from https://github.com/rkt/rkt/issues/1752#issue-117121841
 	//
 	// A->B
 	// A->C
@@ -108,45 +95,72 @@ func generateComplexDependencyTree(t *testing.T, ctx *testutils.RktRunCtx) (map[
 		{
 			shortName: "a",
 			imageName: topImage,
-			deps:      `{"imageName":"localhost/image-b"}, {"imageName":"localhost/image-c"}, {"imageName":"localhost/image-d"}`,
-			version:   "1",
+			deps: types.Dependencies{
+				{ImageName: "localhost/image-b"},
+				{ImageName: "localhost/image-c"},
+				{ImageName: "localhost/image-d"},
+			},
+			version: "1",
 		},
 		{
 			shortName: "b",
 			imageName: "localhost/image-b",
-			deps:      ``,
 			version:   "1",
 			prefetch:  true,
 		},
 		{
 			shortName: "c",
 			imageName: "localhost/image-c",
-			deps:      `{"imageName":"localhost/image-b"}, {"imageName":"localhost/image-e", "labels": [{"name": "version", "value": "1"}]}`,
-			version:   "1",
+			deps: types.Dependencies{
+				{ImageName: "localhost/image-b"},
+				{ImageName: "localhost/image-e",
+					Labels: types.Labels{{"version", "1"}}},
+			},
+			version: "1",
 		},
 		{
 			shortName: "d",
 			imageName: "localhost/image-d",
-			deps:      `{"imageName":"localhost/image-b"}, {"imageName":"localhost/image-e", "labels": [{"name": "version", "value": "1"}]}`,
-			version:   "1",
+			deps: types.Dependencies{
+				{ImageName: "localhost/image-b"},
+				{ImageName: "localhost/image-e",
+					Labels: types.Labels{{"version", "1"}}},
+			},
+			version: "1",
 		},
 		{
 			shortName: "e",
 			imageName: "localhost/image-e",
-			deps:      `{"imageName":"coreos.com/rkt-inspect"}`,
-			version:   "1",
+			deps: types.Dependencies{
+				{ImageName: "coreos.com/rkt-inspect"},
+			},
+			version: "1",
 		},
 	}
 
+	// Copy original labels of the image manifest, as on
+	// the next step this list will be populated with a
+	// version for each test.
+	labels := make(types.Labels, len(manifest.Labels))
+	copy(labels, manifest.Labels)
+
 	for i := range imageList {
 		// We need a reference rather than a new copy from "range"
 		// because we modify the content
 		img := &imageList[i]
 
-		img.manifest = manifestDepsTemplate
-		img.manifest = strings.Replace(img.manifest, "IMG_NAME", img.imageName, -1)
-		img.manifest = strings.Replace(img.manifest, "DEPENDENCIES", img.deps, -1)
-		img.manifest = strings.Replace(img.manifest, "VERSION", img.version, -1)
+		imgLabels := types.Labels{{"version", img.version}}
+
+		// Customize fields of the generic image manifest.
+		manifest.Name = types.ACIdentifier(img.imageName)
+		manifest.Labels = append(imgLabels, labels...)
+		manifest.Dependencies = img.deps
+
+		// Marshal the modified image manifest into JSON string.
+		img.manifest, err = acitest.ImageManifestString(&manifest)
+		if err != nil {
+			t.Fatalf("unexpected error: %v", err)
+		}
 
 		tmpManifest, err := ioutil.TempFile(tmpDir, "manifest-"+img.shortName+"-")
 		if err != nil {
@@ -169,7 +183,7 @@ func generateComplexDependencyTree(t *testing.T, ctx *testutils.RktRunCtx) (map[
 // fetches them via the discovery mechanism. Some dependencies are already
 // cached in the CAS, and some dependencies are fetched via the discovery
 // mechanism. This is to reproduce the scenario in explained in:
-// https://github.com/coreos/rkt/issues/1752#issue-117121841
+// https://github.com/rkt/rkt/issues/1752#issue-117121841
 func TestImageDependencies(t *testing.T) {
 	ctx := testutils.NewRktRunCtx()
 	defer ctx.Cleanup()
@@ -251,7 +265,7 @@ func TestRenderOnFetch(t *testing.T) {
 		}
 	}
 
-	fetchCmd := fmt.Sprintf("%s --debug --insecure-options=image,tls fetch %s", ctx.Cmd(), topImage)
+	fetchCmd := fmt.Sprintf("%s --debug --insecure-options=image,tls fetch --pull-policy=new %s", ctx.Cmd(), topImage)
 	child := spawnOrFail(t, fetchCmd)
 
 	treeStoreDir := filepath.Join(ctx.DataDir(), "cas", "tree")
