@@ -22,7 +22,7 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/coreos/rkt/tests/testutils"
+	"github.com/rkt/rkt/tests/testutils"
 )
 
 // TestImageExtract tests 'rkt image extract', it will import some existing
@@ -35,7 +35,7 @@ func TestImageExtract(t *testing.T) {
 	inspectFile := testutils.GetValueFromEnvOrPanic("INSPECT_BINARY")
 	inspectHash := getHashOrPanic(inspectFile)
 
-	tmpDir := createTempDirOrPanic("rkt-TestImageRender-")
+	tmpDir := mustTempDir("rkt-TestImageRender-")
 	defer os.RemoveAll(tmpDir)
 
 	ctx := testutils.NewRktRunCtx()
