@@ -24,8 +24,8 @@ import (
 	"testing"
 
 	"github.com/coreos/gexpect"
-	"github.com/coreos/rkt/common"
-	"github.com/coreos/rkt/tests/testutils"
+	"github.com/rkt/rkt/common"
+	"github.com/rkt/rkt/tests/testutils"
 )
 
 func TestImageGCTreeStore(t *testing.T) {
