@@ -23,7 +23,7 @@ import (
 	"testing"
 	"time"
 
-	"github.com/coreos/rkt/tests/testutils"
+	"github.com/rkt/rkt/tests/testutils"
 )
 
 const delta = 4 * time.Second
@@ -57,6 +57,14 @@ func TestRktList(t *testing.T) {
 	// Get hash
 	imageID := fmt.Sprintf("sha512-%s", imgID.hash[:12])
 
+	cmd = fmt.Sprintf("%s --insecure-options=image run-prepared %s", ctx.Cmd(), podUuid)
+	nobodyUid, _ := testutils.GetUnprivilegedUidGid()
+	_, status := runRkt(t, cmd, nobodyUid, 0)
+	if status != 0 {
+		panic(fmt.Errorf("expected exit status code 0, got %d", status))
+	}
+	podInfo := getPodInfo(t, ctx, podUuid)
+	ipv4 := podInfo.networks["default"].ipv4
 	// Define tests
 	tests := []struct {
 		cmd           string
@@ -99,6 +107,12 @@ func TestRktList(t *testing.T) {
 			true,
 			imageID,
 		},
+		//	Test that ip is in json output
+		{
+			"list --format=json",
+			true,
+			ipv4,
+		},
 	}
 
 	// Run tests
@@ -158,7 +172,7 @@ func TestRktListCreatedStarted(t *testing.T) {
 	// Get hash
 	imageID := fmt.Sprintf("sha512-%s", imgID.hash[:12])
 
-	tmpDir := createTempDirOrPanic(imgName)
+	tmpDir := mustTempDir(imgName)
 	defer os.RemoveAll(tmpDir)
 
 	time.Sleep(delta)
