@@ -40,3 +40,11 @@ func TestNetLongName(t *testing.T) {
 func TestNetDefaultRestrictedConnectivity(t *testing.T) {
 	NewTestNetDefaultRestrictedConnectivity().Execute(t)
 }
+
+func TestNetPreserveNetName(t *testing.T) {
+	NewNetPreserveNetNameTest().Execute(t)
+}
+
+func TestNetDefaultGW(t *testing.T) {
+	NewNetDefaultGWTest().Execute(t)
+}
