@@ -24,10 +24,10 @@ import (
 
 	"github.com/appc/spec/schema"
 	"github.com/appc/spec/schema/types"
-	"github.com/coreos/rkt/tests/testutils"
+	"github.com/rkt/rkt/tests/testutils"
 	"github.com/syndtr/gocapability/capability"
 
-	"github.com/coreos/rkt/common/cgroup"
+	"github.com/rkt/rkt/common/cgroup"
 )
 
 func intP(i int) *int {
@@ -51,7 +51,7 @@ func TestPodManifest(t *testing.T) {
 	ctx := testutils.NewRktRunCtx()
 	defer ctx.Cleanup()
 
-	tmpdir := createTempDirOrPanic("rkt-tests.")
+	tmpdir := mustTempDir("rkt-tests.")
 	defer os.RemoveAll(tmpdir)
 
 	boolFalse, boolTrue := false, true
@@ -1286,7 +1286,7 @@ func TestPodManifestWithEmptyApps(t *testing.T) {
 	ctx := testutils.NewRktRunCtx()
 	defer ctx.Cleanup()
 
-	tmpdir := createTempDirOrPanic("rkt-tests.")
+	tmpdir := mustTempDir("rkt-tests.")
 	defer os.RemoveAll(tmpdir)
 
 	manifest := &schema.PodManifest{
