@@ -26,7 +26,7 @@ import (
 
 	sd_dbus "github.com/coreos/go-systemd/dbus"
 	sd_util "github.com/coreos/go-systemd/util"
-	"github.com/coreos/rkt/tests/testutils"
+	"github.com/rkt/rkt/tests/testutils"
 )
 
 func TestServiceFile(t *testing.T) {
